# pdfid

[![PyPI version](https://badge.fury.io/py/pdfid.svg)](https://badge.fury.io/py/pdfid)

This is a clone of Didier Steven's [tool](https://github.com/DidierStevens/DidierStevensSuite/blob/master/pdfid.py) created to publish it into Pypi and make it usable as a library.

See `test.py` for an example of usage

